<?php
/**
 * Group create template
 *
 * @package    Community_Builder
 * @subpackage BuddyPress
 * @copyright  Copyright (c) 2019, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 */

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Fires at the top of the groups creation template file.
 */
do_action( 'bp_before_create_group_page' );
?>

<div id="buddypress">

	<?php

	/**
	 * Fires before the display of group creation content.
	 */
	do_action( 'bp_before_create_group_content_template' );
	?>

	<form action="<?php bp_group_creation_form_action(); ?>" method="post" id="create-group-form" class="standard-form group-setup-form" enctype="multipart/form-data">

		<?php

		/**
		 * Fires before the display of group creation.
		 */
		do_action( 'bp_before_create_group' );
		?>
		<div class="<?php cb_bp_dir_item_nav_css_class( array( 'component' => 'activity', 'type'=> 'primary' , 'class' => 'bp-groups-create-nav' ) );?>  ">
			<div class="<?php cb_bp_dir_item_tabs_css_class( array( 'component'=> 'groups', 'type'=> 'primary', 'class' => ' no-greedy-nav no-ajax bp-groups-create-nav-tabs' ) ); ?>" id="group-create-tabs" role="navigation">
				<ul>
					<?php bp_group_creation_tabs(); ?>
				</ul>
			</div><!-- .item-list-tabs -->

		</div><!-- end of .bp-nav -->

		<div class="item-body <?php bp_groups_current_create_step(); ?>" id="group-create-body">

		<?php /* Group creation step 1: Basic group details */ ?>
			<?php if ( bp_is_group_creation_step( 'group-details' ) ) : ?>

				<h2 class="bp-screen-reader-text"><?php
					/* translators: accessibility text */
					_e( 'Group Details', 'community-builder' );
					?>
				</h2>
				<?php

				/**
				 * Fires before the display of the group details creation step.
				 */
				do_action( 'bp_before_group_details_creation_step' );
				?>

				<div class="form-row group-name-row">
					<label for="group-name"><?php _e( 'Group Name (required)', 'community-builder' ); ?></label>
					<input type="text" name="group-name" id="group-name" aria-required="true" value="<?php bp_new_group_name(); ?>" />
				</div>

				<div class="form-row group-desc-row">
					<label for="group-desc"><?php _e( 'Group Description (required)', 'community-builder' ); ?></label>
					<textarea name="group-desc" id="group-desc" aria-required="true"><?php bp_new_group_description(); ?></textarea>
				</div>

				<?php

				/**
				 * Fires after the display of the group details creation step.
				 */
				do_action( 'bp_after_group_details_creation_step' );

				wp_nonce_field( 'groups_create_save_group-details' );
				?>

			<?php endif; ?>

			<?php /* Group creation step 2: Group settings */ ?>
			<?php if ( bp_is_group_creation_step( 'group-settings' ) ) : ?>

				<h2 class="bp-screen-reader-text"><?php
					/* translators: accessibility text */
					_e( 'Group Settings', 'community-builder' );
					?>
				</h2>

				<?php

				/**
				 * Fires before the display of the group settings creation step.
				 */
				do_action( 'bp_before_group_settings_creation_step' );
				?>
				<fieldset class="group-settings-privacy group-create-privacy">
					<legend><?php _e( 'Privacy Options', 'community-builder' ); ?></legend>

					<div class="radio">
						<label for="group-status-public"><input type="radio" name="group-status" id="group-status-public" value="public"<?php if ( 'public' == bp_get_new_group_status() || !bp_get_new_group_status() ) { ?> checked="checked"<?php } ?> /> <strong><?php _e( 'This is a public group', 'community-builder' ); ?></strong></label>
						<ul id="public-group-description">
							<li><?php _e( 'Any site member can join this group.', 'community-builder' ); ?></li>
							<li><?php _e( 'This group will be listed in the groups directory and in search results.', 'community-builder' ); ?></li>
							<li><?php _e( 'Group content and activity will be visible to any site member.', 'community-builder' ); ?></li>
						</ul>


						<label for="group-status-private">
							<input type="radio" name="group-status" id="group-status-private" value="private"<?php if ( 'private' == bp_get_new_group_status() ) { ?> checked="checked"<?php } ?> />
							<strong><?php _e( 'This is a private group', 'community-builder' ); ?></strong>
						</label>
						<ul id="private-group-description">
							<li><?php _e( 'Only users who request membership and are accepted can join the group.', 'community-builder' ); ?></li>
							<li><?php _e( 'This group will be listed in the groups directory and in search results.', 'community-builder' ); ?></li>
							<li><?php _e( 'Group content and activity will only be visible to members of the group.', 'community-builder' ); ?></li>
						</ul>


						<label for="group-status-hidden">
							<input type="radio" name="group-status" id="group-status-hidden" value="hidden"<?php if ( 'hidden' == bp_get_new_group_status() ) { ?> checked="checked"<?php } ?> />
							<strong><?php _e('This is a hidden group', 'community-builder' ); ?></strong>
						</label>
						<ul id="hidden-group-description">
							<li><?php _e( 'Only users who are invited can join the group.', 'community-builder' ); ?></li>
							<li><?php _e( 'This group will not be listed in the groups directory or search results.', 'community-builder' ); ?></li>
							<li><?php _e( 'Group content and activity will only be visible to members of the group.', 'community-builder' ); ?></li>
						</ul>

					</div>
				</fieldset>

				<?php // Group type selection ?>
				<?php if (  function_exists( 'bp_groups_get_group_types' ) && $group_types = bp_groups_get_group_types( array( 'show_in_create_screen' => true ), 'objects' ) ): ?>

					<fieldset class="group-create-types">
						<legend><?php _e( 'Group Types', 'community-builder' ); ?></legend>

						<p><?php _e( 'Select the types this group should be a part of.', 'community-builder' ); ?></p>

						<?php foreach ( $group_types as $type ) : ?>
							<div class="form-text-secondary checkbox ">
								<label for="<?php printf( 'group-type-%s', $type->name ); ?>"><input type="checkbox" name="group-types[]" id="<?php printf( 'group-type-%s', $type->name ); ?>" value="<?php echo esc_attr( $type->name ); ?>" <?php checked( true, ! empty( $type->create_screen_checked ) ); ?> /> <?php echo esc_html( $type->labels['name'] ); ?>
									<?php
									if ( ! empty( $type->description ) ) {
										/* translators: Group type description shown when creating a group. */
										printf( __( '&ndash; %s', 'community-builder' ), '<span class="bp-group-type-desc">' . esc_html( $type->description ) . '</span>' );
									}
									?>
								</label>
							</div>
						<?php endforeach; ?>

					</fieldset>

				<?php endif; ?>

				<fieldset class="group-settings-invitations group-create-invitations">
					<legend><?php _e( 'Group Invitations', 'community-builder' ); ?></legend>

					<p><?php _e( 'Which members of this group are allowed to invite others?', 'community-builder' ); ?></p>

					<div class="radio">
						<label>
							<input type="radio" name="group-invite-status" value="members"<?php bp_group_show_invite_status_setting( 'members' ); ?> />
							<strong><?php _e( 'All group members', 'community-builder' ); ?></strong>
						</label>

						<label>
							<input type="radio" name="group-invite-status" value="mods"<?php bp_group_show_invite_status_setting( 'mods' ); ?> />
							<strong><?php _e( 'Group admins and mods only', 'community-builder' ); ?></strong>
						</label>

						<label>
							<input type="radio" name="group-invite-status" value="admins"<?php bp_group_show_invite_status_setting( 'admins' ); ?> />
							<strong><?php _e( 'Group admins only', 'community-builder' ); ?></strong>
						</label>
					</div>
				</fieldset>

				<?php if ( bp_is_active( 'forums' ) ) : ?>

					<h4><?php _e( 'Group Forums', 'community-builder' ); ?></h4>

					<?php if ( bp_forums_is_installed_correctly() ) : ?>

						<p><?php _e( 'Should this group have a forum?', 'community-builder' ); ?></p>

						<div class="checkbox">
							<label><input type="checkbox" name="group-show-forum" id="group-show-forum" value="1"<?php checked( bp_get_new_group_enable_forum(), true, true ); ?> /> <?php _e( 'Enable discussion forum', 'community-builder' ); ?></label>
						</div>
					<?php elseif ( is_super_admin() ) : ?>
						<p><?php
                            /* translators: %s: Forum setup url */
                            printf( __( '<strong>Attention Site Admin:</strong> Group forums require the <a href="%s">correct setup and configuration</a> of a bbPress installation.', 'community-builder' ), bp_core_do_network_admin() ? network_admin_url( 'settings.php?page=bb-forums-setup' ) :  admin_url( 'admin.php?page=bb-forums-setup' ) ); ?>
                        </p>
					<?php endif; ?>

				<?php endif; ?>

				<?php

				/**
				 * Fires after the display of the group settings creation step.
				 */
				do_action( 'bp_after_group_settings_creation_step' );
				?>

				<?php wp_nonce_field( 'groups_create_save_group-settings' ); ?>

			<?php endif; ?>

			<?php /* Group creation step 3: Avatar Uploads */ ?>
			<?php if ( bp_is_group_creation_step( 'group-avatar' ) ) : ?>

				<?php

				/**
				 * Fires before the display of the group avatar creation step.
				 */
				do_action( 'bp_before_group_avatar_creation_step' );
				?>

				<?php if ( 'upload-image' == bp_get_avatar_admin_step() ) : ?>

					<div class="left-menu">

						<?php bp_new_group_avatar(); ?>

					</div><!-- .left-menu -->

					<div class="main-column">
						<?php
						/**
						 * Load the Avatar UI templates
						 */
						bp_avatar_get_templates();
						?>

						<p><?php _e( "Upload an image to use as a profile photo for this group. The image will be shown on the main group page, and in search results.", 'community-builder' ); ?></p>

						<p>
							<input type="file" name="file" id="file" />
							<input type="submit" name="upload" id="upload" value="<?php esc_attr_e( 'Upload Image', 'community-builder' ); ?>" />
							<input type="hidden" name="action" id="action" value="bp_avatar_upload" />
						</p>

						<p><?php _e( 'To skip the group profile photo upload process, hit the "Next Step" button.', 'community-builder' ); ?></p>
					</div><!-- .main-column -->

				<?php endif; ?>

				<?php if ( 'crop-image' == bp_get_avatar_admin_step() ) : ?>

					<h4><?php _e( 'Crop Group Profile Photo', 'community-builder' ); ?></h4>

					<img src="<?php bp_avatar_to_crop(); ?>" id="avatar-to-crop" class="avatar" alt="<?php esc_attr_e( 'Profile photo to crop', 'community-builder' ); ?>" />

					<div id="avatar-crop-pane">
						<img src="<?php bp_avatar_to_crop(); ?>" id="avatar-crop-preview" class="avatar" alt="<?php esc_attr_e( 'Profile photo preview', 'community-builder' ); ?>" />
					</div>

					<input type="submit" name="avatar-crop-submit" id="avatar-crop-submit" value="<?php esc_attr_e( 'Crop Image', 'community-builder' ); ?>" />

					<input type="hidden" name="image_src" id="image_src" value="<?php bp_avatar_to_crop_src(); ?>" />
					<input type="hidden" name="upload" id="upload" />
					<input type="hidden" id="x" name="x" />
					<input type="hidden" id="y" name="y" />
					<input type="hidden" id="w" name="w" />
					<input type="hidden" id="h" name="h" />

				<?php endif; ?>

				<?php

				/**
				 * Fires after the display of the group avatar creation step.
				 */
				do_action( 'bp_after_group_avatar_creation_step' );
				?>

				<?php wp_nonce_field( 'groups_create_save_group-avatar' ); ?>

			<?php endif; ?>
			<?php /* Group creation step 4: Cover image */ ?>
			<?php if ( bp_is_group_creation_step( 'group-cover-image' ) ) : ?>
				<h2 class="bp-screen-reader-text"><?php
					/* translators: accessibility text */
					_e( 'Cover Image', 'community-builder' );
					?>
				</h2>
				<?php

				/**
				 * Fires before the display of the group cover image creation step.
				 */
				do_action( 'bp_before_group_cover_image_creation_step' );
				?>

				<div id="header-cover-image"></div>


				<?php bp_attachments_get_template_part( 'cover-images/index' ); ?>

				<p><?php _e( 'The Cover Image will be used to customize the header of your group.', 'community-builder' ); ?></p>

				<?php

				/**
				 * Fires after the display of the group cover image creation step.
				 */
				do_action( 'bp_after_group_cover_image_creation_step' );
				?>

				<?php wp_nonce_field( 'groups_create_save_group-cover-image' ); ?>

			<?php endif; ?>

			<?php /* Group creation step 5: Invite friends to group */ ?>
			<?php if ( bp_is_group_creation_step( 'group-invites' ) ) : ?>

				<?php

				/**
				 * Fires before the display of the group invites creation step.
				 */
				do_action( 'bp_before_group_invites_creation_step' );
				?>

				<?php if ( bp_is_active( 'friends' ) && bp_get_total_friend_count( bp_loggedin_user_id() ) ) : ?>

					<div class="invite clearfix">
						<?php bp_get_template_part( 'groups/single/invites-loop' ); ?>
					</div>

				<?php else : ?>

					<div id="message" class="info">
						<p><?php _e( 'Once you have built up friend connections you will be able to invite others to your group.', 'community-builder' ); ?></p>
					</div>

				<?php endif; ?>

				<?php wp_nonce_field( 'groups_create_save_group-invites' ); ?>

				<?php

				/**
				 * Fires after the display of the group invites creation step.
				 */
				do_action( 'bp_after_group_invites_creation_step' );
				?>

			<?php endif; ?>

			<?php

			/**
			 * Fires inside the group admin template.
			 *
			 * Allows plugins to add custom group creation steps.
			 */
			do_action( 'groups_custom_create_steps' );
			?>

			<?php

			/**
			 * Fires before the display of the group creation step buttons.
			 */
			do_action( 'bp_before_group_creation_step_buttons' );
			?>

			<?php if ( 'crop-image' != bp_get_avatar_admin_step() ) : ?>

				<div class="submit" id="previous-next">

					<?php /* Previous Button */ ?>
					<?php if ( ! bp_is_first_group_creation_step() ) : ?>

						<input class="btn" type="button" value="<?php esc_attr_e( 'Back to Previous Step', 'community-builder' ); ?>" id="group-creation-previous" name="previous" onclick="location.href='<?php bp_group_creation_previous_link(); ?>'" />

					<?php endif; ?>

					<?php /* Next Button */ ?>
					<?php if ( ! bp_is_last_group_creation_step() && ! bp_is_first_group_creation_step() ) : ?>

						<input type="submit" value="<?php esc_attr_e( 'Next Step', 'community-builder' ); ?>" id="group-creation-next" name="save" />

					<?php endif; ?>

					<?php /* Create Button */ ?>
					<?php if ( bp_is_first_group_creation_step() ) : ?>

						<input type="submit" value="<?php esc_attr_e( 'Create Group and Continue', 'community-builder' ); ?>" id="group-creation-create" name="save" />

					<?php endif; ?>

					<?php /* Finish Button */ ?>

					<?php if ( bp_is_last_group_creation_step() ) : ?>
						<input type="submit" value="<?php esc_attr_e( 'Finish', 'community-builder' ); ?>" id="group-creation-finish" name="save" />
					<?php endif; ?>

				</div>

			<?php
			endif;

			/**
			 * Fires after the display of the group creation step buttons.
			 */
			do_action( 'bp_after_group_creation_step_buttons' );
			?>

			<?php /* Don't leave out this hidden field */ ?>
			<input type="hidden" name="group_id" id="group_id" value="<?php bp_new_group_id(); ?>" />

			<?php

			/**
			 * Fires and displays the groups directory content.
			 */
			do_action( 'bp_directory_groups_content' );
			?>

		</div><!-- .item-body -->

		<?php

		/**
		 * Fires after the display of group creation.
		 */
		do_action( 'bp_after_create_group' );
		?>

	</form>

	<?php

	/**
	 * Fires after the display of group creation content.
	 */
	do_action( 'bp_after_create_group_content_template' );
	?>

</div>

<?php

/**
 * Fires at the bottom of the groups creation template file.
 */
do_action( 'bp_after_create_group_page' );
