<?php
/**
 * BuddyPress - Groups Admin - Group Settings
 *
 * @package    Community_Builder
 * @subpackage BuddyPress
 * @copyright  Copyright (c) 2019, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 */

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

?>
<h4 class="bp-screen-reader-text"><?php _e( 'Manage Group Settings', 'community-builder' ); ?></h4>

<?php
/**
 * Fires before the group settings admin display.
 */
do_action( 'bp_before_group_settings_admin' );
?>

<fieldset class="group-settings-privacy group-create-privacy">
	<legend><?php _e( 'Privacy Options', 'community-builder' ); ?></legend>

	<div class="radio">

		<label for="group-status-public"><input type="radio" name="group-status" id="group-status-public" value="public"<?php if ( 'public' == bp_get_new_group_status() || !bp_get_new_group_status() ) { ?> checked="checked"<?php } ?> aria-describedby="public-group-description" /> <?php _e( 'This is a public group', 'community-builder' ); ?></label>

		<ul id="public-group-description">
			<li><?php _e( 'Any site member can join this group.', 'community-builder' ); ?></li>
			<li><?php _e( 'This group will be listed in the groups directory and in search results.', 'community-builder' ); ?></li>
			<li><?php _e( 'Group content and activity will be visible to any site member.', 'community-builder' ); ?></li>
		</ul>

		<label for="group-status-private"><input type="radio" name="group-status" id="group-status-private" value="private"<?php if ( 'private' == bp_get_new_group_status() ) { ?> checked="checked"<?php } ?> aria-describedby="private-group-description" /> <?php _e( 'This is a private group', 'community-builder' ); ?></label>

		<ul id="private-group-description">
			<li><?php _e( 'Only users who request membership and are accepted can join the group.', 'community-builder' ); ?></li>
			<li><?php _e( 'This group will be listed in the groups directory and in search results.', 'community-builder' ); ?></li>
			<li><?php _e( 'Group content and activity will only be visible to members of the group.', 'community-builder' ); ?></li>
		</ul>

		<label for="group-status-hidden"><input type="radio" name="group-status" id="group-status-hidden" value="hidden"<?php if ( 'hidden' == bp_get_new_group_status() ) { ?> checked="checked"<?php } ?> aria-describedby="hidden-group-description" /> <?php _e('This is a hidden group', 'community-builder' ); ?></label>

		<ul id="hidden-group-description">
			<li><?php _e( 'Only users who are invited can join the group.', 'community-builder' ); ?></li>
			<li><?php _e( 'This group will not be listed in the groups directory or search results.', 'community-builder' ); ?></li>
			<li><?php _e( 'Group content and activity will only be visible to members of the group.', 'community-builder' ); ?></li>
		</ul>

	</div>

</fieldset>

<?php // Group type selection ?>
<?php if ( function_exists( 'bp_groups_get_group_types' ) && $group_types = bp_groups_get_group_types( array( 'show_in_create_screen' => true ), 'objects' ) ): ?>

	<fieldset class="group-create-types">
		<legend><?php _e( 'Group Types', 'community-builder' ); ?></legend>

		<p><?php _e( 'Select the types this group should be a part of.', 'community-builder' ); ?></p>

		<?php foreach ( $group_types as $type ) : ?>
			<div class="checkbox form-text-secondary">
				<label for="<?php printf( 'group-type-%s', $type->name ); ?>">
					<input type="checkbox" name="group-types[]" id="<?php printf( 'group-type-%s', $type->name ); ?>" value="<?php echo esc_attr( $type->name ); ?>" <?php checked( bp_groups_has_group_type( bp_get_current_group_id(), $type->name ) ); ?>/> <?php echo esc_html( $type->labels['name'] ); ?>
					<?php
					if ( ! empty( $type->description ) ) {
						printf( __( '&ndash; %s', 'community-builder' ), '<span class="bp-group-type-desc">' . esc_html( $type->description ) . '</span>' );
					}
					?>
				</label>
			</div>
		<?php endforeach; ?>

	</fieldset>

<?php endif; ?>

<fieldset class="group-settings-invitations group-create-invitations">
	<legend><?php _e( 'Group Invitations', 'community-builder' ); ?></legend>

	<p><?php _e( 'Which members of this group are allowed to invite others?', 'community-builder' ); ?></p>

	<div class="radio">
		<label for="group-invite-status-members"><input type="radio" name="group-invite-status" id="group-invite-status-members" value="members"<?php bp_group_show_invite_status_setting( 'members' ); ?> /> <?php _e( 'All group members', 'community-builder' ); ?></label>
		<label for="group-invite-status-mods"><input type="radio" name="group-invite-status" id="group-invite-status-mods" value="mods"<?php bp_group_show_invite_status_setting( 'mods' ); ?> /> <?php _e( 'Group admins and mods only', 'community-builder' ); ?></label>
		<label for="group-invite-status-admins"><input type="radio" name="group-invite-status" id="group-invite-status-admins" value="admins"<?php bp_group_show_invite_status_setting( 'admins' ); ?> /> <?php _e( 'Group admins only', 'community-builder' ); ?></label>
	</div>

</fieldset>

<?php
/**
 * Fires after the group settings admin display.
 */
do_action( 'bp_after_group_settings_admin' ); ?>
<div class="submit">
	<input type="submit" value="<?php esc_attr_e( 'Save Changes', 'community-builder' ); ?>" id="save" name="save" /></p>
</div>
<?php
wp_nonce_field( 'groups_edit_group_settings' );
