<?php
/**
 * Blog Panel customize settings.
 *
 * @package    Community_Builder
 * @subpackage Customizer\Panels
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 */

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Helper.
 */
class CB_Customize_Panel_Blog {

	/**
	 * Panel id.
	 *
	 * @var string
	 */
	private $panel = 'cb_blog';

	/**
	 * CB_Customize_Panel_Blog constructor.
	 */
	public function __construct() {
		add_filter( 'cb_customizer_sections', array( $this, 'add_sections' ) );
	}

	/**
	 * Add customizable sections.
	 *
	 * @param array $sections sections.
	 *
	 * @return array
	 */
	public function add_sections( $sections ) {

		$new_sections = $this->get_sections();

		return array_merge( $sections, $new_sections );
	}

	/**
	 * Get all sections.
	 *
	 * @return array
	 */
	public function get_sections() {

		$sections = array();
		$panel    = $this->panel;

		$sections['home-posts-list'] = array(
			'panel'       => $panel,
			'title'       => __( 'Home Page', 'community-builder' ),
			'description' => __( 'Posts display settings.', 'community-builder' ),
			'options'     => array(
				'home-posts-display-type' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_choice' ),
						'default'           => cb_get_default( 'home-posts-display-type' ),
						'transport'         => 'refresh',
					),
					'control' => array(
						'type'        => 'select',
						'choices'     => CB_Settings_Choices::get( 'home-posts-display-type' ),
						'label'       => __( 'Post list display type?', 'community-builder' ),
						'description' => __( 'Will be used for listing posts.', 'community-builder' ),
					),
				),
				'home-posts-per-row' => array(
					'setting' => array(
						'sanitize_callback' => 'absint',
						'default'           => cb_get_default( 'home-posts-per-row' ),
						'transport'         => 'refresh',
					),
					'control' => array(
						'control_type'    => 'CB_Customize_Control_Range',
						'input_attrs'     => array(
							'min'  => 1,
							'max'  => 6,
							'step' => 1,
						),
						'label'           => __( 'Posts Per row?', 'community-builder' ),
						'description'     => __( 'Posts per row when using masonry layout.', 'community-builder' ),
						'active_callback' => 'cb_is_home_page_using_masonry',
					),
				),

			), // end of options.
		); // end of page section.

		$sections['blog-archive-post'] = array(
			'panel'       => $panel,
			'title'       => __( 'Archive', 'community-builder' ),
			'description' => __( 'Posts display settings.', 'community-builder' ),
			'options'     => array(
				'archive-show-page-header'  => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_int' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'archive-show-page-header' ),
					),
					'control' => array(
						'type'        => 'checkbox',
						'input_attrs' => array(),
						'label'       => __( 'Show page header?', 'community-builder' ),
						'description' => __( 'Do you want to show the main page header?.', 'community-builder' ),
					),
				),
				'archive-page-header-items' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_multi_choices' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'archive-page-header-items' ),
					),
					'control' => array(
						'control_type'    => 'CB_Customize_Control_Checkbox_Multiple',
						'input_attrs'     => array(),
						'choices'         => CB_Settings_Choices::get( 'archive-page-header-items' ),
						'label'           => __( 'Show In Page Header?', 'community-builder' ),
						'description'     => __( 'Things to show in page header.', 'community-builder' ),
						'active_callback' => 'cb_is_page_header_control_active',
					),
				),

				'archive-posts-display-type' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_choice' ),
						'default'           => cb_get_default( 'archive-posts-display-type' ),
						'transport'         => 'refresh',
					),
					'control' => array(
						'type'        => 'select',
						'choices'     => CB_Settings_Choices::get( 'archive-posts-display-type' ),
						'label'       => __( 'Post list display type?', 'community-builder' ),
						'description' => __( 'Will be used for listing posts.', 'community-builder' ),
					),
				),
				'archive-posts-per-row'      => array(
					'setting' => array(
						'sanitize_callback' => 'absint',
						'default'           => cb_get_default( 'archive-posts-per-row' ),
						'transport'         => 'refresh',
					),
					'control' => array(
						'control_type'    => 'CB_Customize_Control_Range',
						'input_attrs'     => array(
							'min'  => 1,
							'max'  => 6,
							'step' => 1,
						),
						'label'           => __( 'Posts Per row?', 'community-builder' ),
						'description'     => __( 'Posts per row when using masonry layout.', 'community-builder' ),
						'active_callback' => 'cb_is_archive_page_using_masonry',
					),
				),
				'archive-article-items' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_multi_choices' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'archive-article-items' ),
					),
					'control' => array(
						'control_type' => 'CB_Customize_Control_Checkbox_Multiple',
						'input_attrs'  => array(),
						'choices'      => CB_Settings_Choices::get( 'archive-article-items' ),
						'label'        => __( 'Enable in post entry?', 'community-builder' ),
						'description'  => __( 'Do you want to show it in each post entry?', 'community-builder' ),
					),
				),
				'archive-post-header-meta' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_multi_choices' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'archive-post-header-meta' ),
					),
					'control' => array(
						'control_type' => 'CB_Customize_Control_Sortable',
						'input_attrs'  => array(),
						'label'        => __( 'Article header meta', 'community-builder' ),
						'description'  => __( 'Control article header meta on archives.', 'community-builder' ),
						'choices'      => CB_Settings_Choices::get( 'archive-post-header-meta' ),
					),
				),
				'archive-post-footer-meta' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_multi_choices' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'archive-post-footer-meta' ),
					),
					'control' => array(
						'control_type' => 'CB_Customize_Control_Sortable',
						'input_attrs'  => array(),
						'label'        => __( 'Article footer meta', 'community-builder' ),
						'description'  => __( 'Control article footer meta on archives.', 'community-builder' ),
						'choices'      => CB_Settings_Choices::get( 'archive-post-footer-meta' ),
					),
				),

			), // end of options.
		); // end of page section.


		$sections['search-posts-list'] = array(
			'panel'       => $panel,
			'title'       => __( 'Search Page', 'community-builder' ),
			'description' => __( 'Posts display settings.', 'community-builder' ),
			'options'     => array(
				'search-posts-display-type' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_choice' ),
						'default'           => cb_get_default( 'search-posts-display-type' ),
						'transport'         => 'refresh',
					),
					'control' => array(
						'type'        => 'select',
						'choices'     => CB_Settings_Choices::get( 'search-posts-display-type' ),
						'label'       => __( 'Post list display type?', 'community-builder' ),
						'description' => __( 'Will be used for listing posts.', 'community-builder' ),
					),
				),
				'search-posts-per-row' => array(
					'setting' => array(
						'sanitize_callback' => 'absint',
						'default'           => cb_get_default( 'search-posts-per-row' ),
						'transport'         => 'refresh',
					),
					'control' => array(
						'control_type'    => 'CB_Customize_Control_Range',
						'input_attrs'     => array(
							'min'  => 1,
							'max'  => 6,
							'step' => 1,
						),
						'label'           => __( 'Posts Per row?', 'community-builder' ),
						'description'     => __( 'Posts per row when using masonry layout.', 'community-builder' ),
						'active_callback' => 'cb_is_search_page_using_masonry',
					),
				),

			), // end of options.
		); // end of page section.

		$sections['blog-single-page'] = array(
			'panel'       => $panel,
			'title'       => __( 'Page', 'community-builder' ),
			'description' => __( 'Page display settings.', 'community-builder' ),
			'options'     => array(
				'page-show-page-header'  => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_int' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'page-show-page-header' ),
					),
					'control' => array(
						'type'        => 'checkbox',
						'input_attrs' => array(),
						'label'       => __( 'Show Page Header?', 'community-builder' ),
						'description' => __( 'Do you want to show the large page header?.', 'community-builder' ),
					),
				),
				'page-page-header-items' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_multi_choices' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'page-page-header-items' ),
					),
					'control' => array(
						'control_type'    => 'CB_Customize_Control_Checkbox_Multiple',
						'input_attrs'     => array(),
						'choices'         => CB_Settings_Choices::get( 'page-page-header-items' ),
						'label'           => __( 'Show In Page Header?', 'community-builder' ),
						'description'     => __( 'Things to show in page header.', 'community-builder' ),
						'active_callback' => 'cb_is_page_header_control_active',
					),
				),

				'page-article-items' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_multi_choices' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'page-article-items' ),
					),
					'control' => array(
						'control_type' => 'CB_Customize_Control_Checkbox_Multiple',
						'input_attrs'  => array(),
						'choices'      => CB_Settings_Choices::get( 'page-article-items' ),
						'label'        => __( 'Show In Entry?', 'community-builder' ),
						'description'  => __( 'Do you want to show in content entry area?.', 'community-builder' ),
					),
				),


			), // end of options.
		); // end of page section.

		$post_types = cb_get_customizable_post_types();
		$post_types = array_diff( $post_types, array( 'page', 'product' ) ); // we handle page and product separately.

		foreach ( $post_types as $post_type_name ) {
			$post_type_object = get_post_type_object( $post_type_name );

			$sections[ 'blog-single-' . $post_type_name ] = $this->get_post_type_settings( $post_type_name, $post_type_object, $panel );
		}

		$sections['misc-blog-section'] = array(
			'panel'       => $panel,
			'title'       => __( 'Misc Settings', 'community-builder' ),
			'description' => __( 'Miscellaneous settings.', 'community-builder' ),
			'options'     => array(
				'use-post-thumbnail-in-page-header' => array(
					'setting' => array(
						'sanitize_callback' => 'absint',
						'default'           => cb_get_default( 'use-post-thumbnail-in-page-header' ),
						'transport'         => 'refresh',
						'std'               => 1,
					),
					'control' => array(
						'type'        => 'checkbox',
						'label'       => __( 'Use featured image as page header background?', 'community-builder' ),
						'description' => __( 'If you disable it, article featured images will be used as page header background.', 'community-builder' ),
					),
				),
				'featured-image-fit-container' => array(
					'setting' => array(
						'sanitize_callback' => 'absint',
						'default'           => cb_get_default( 'featured-image-fit-container' ),
						'transport'         => 'refresh',
						'std'               => 1,
					),
					'control' => array(
						'type'        => 'checkbox',
						'label'       => __( 'Resize featured image to fit container?', 'community-builder' ),
						'description' => __( 'If you disable it, featured images will not be scaled.', 'community-builder' ),
					),
				),

			), // end of options.
		); // end of page section.

		return apply_filters( 'cb_customizer_blog_sections', $sections );
	}

	/**
	 * Get post type settings.
	 *
	 * @param string       $post_type post type name.
	 * @param WP_Post_Type $post_type_object post type object.
	 * @param string       $panel panel id.
	 *
	 * @return array
	 */
	private function get_post_type_settings( $post_type, $post_type_object, $panel ) {
		$singular_label = $post_type_object->labels->singular_name;

		return array(
			'panel'       => $panel,
			'title'       => $singular_label,
			/* translators: Post type label */
			'description' => sprintf( __( '%s display settings.', 'community-builder' ), $singular_label ),
			'options'     => array(
				$post_type . '-show-page-header'  => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_int' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'post-show-page-header' ),
					),
					'control' => array(
						'type'        => 'checkbox',
						'input_attrs' => array(),
						'label'       => __( 'Show Page Header?', 'community-builder' ),
						'description' => __( 'Do you want to show the main page header?', 'community-builder' ),
					),
				),
				$post_type . '-page-header-items' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_multi_choices' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( $post_type . '-page-header-items' ),
					),
					'control' => array(
						'control_type'    => 'CB_Customize_Control_Checkbox_Multiple',
						'input_attrs'     => array(),
						'choices'         => CB_Settings_Choices::get( 'post-page-header-items' ),
						'label'           => __( 'Show In Page Header?', 'community-builder' ),
						'description'     => __( 'Things to show in page header.', 'community-builder' ),
						'active_callback' => 'cb_is_page_header_control_active',
					),
				),
				$post_type . '-article-items'     => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_multi_choices' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( $post_type . '-article-items' ),
					),
					'control' => array(
						'control_type' => 'CB_Customize_Control_Checkbox_Multiple',
						'input_attrs'  => array(),
						'choices'      => CB_Settings_Choices::get( 'post-article-items' ),
						'label'        => __( 'Show in Content entry?', 'community-builder' ),
						'description'  => __( 'Things to show in content entry section.', 'community-builder' ),
					),
				),
				$post_type . '-header-meta' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_multi_choices' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'post-header-meta' ),
					),
					'control' => array(
						'control_type' => 'CB_Customize_Control_Sortable',
						'input_attrs'  => array(),
						'label'        => __( 'Article header meta', 'community-builder' ),
						'description'  => __( 'Control article footer meta on single article page.', 'community-builder' ),
						'choices'      => CB_Settings_Choices::get( 'post-header-meta' ),
					),
				),
				$post_type . '-footer-meta' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_multi_choices' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'post-footer-meta' ),
					),
					'control' => array(
						'control_type' => 'CB_Customize_Control_Sortable',
						'input_attrs'  => array(),
						'label'        => __( 'Article footer meta', 'community-builder' ),
						'description'  => __( 'Control article footer meta on single article page.', 'community-builder' ),
						'choices'      => CB_Settings_Choices::get( 'post-footer-meta' ),
					),
				),


			), // end of options.
		); // end of page section.
	}
} // end of class.

new CB_Customize_Panel_Blog();
